@@ -9,16 +9,16 @@ Puppet::Type.type(:trove_datastore).provide(
     Trove provider to manage datastore type.
   EOT
 
-  commands :trove => "trove"
-
   mk_resource_methods
 
+  @credentials = Puppet::Provider::Openstack::CredentialsV3.new
+
   def self.instances
-    list_trove_resources("datastore").collect do |attrs|
+    request('datastore', 'list').collect do |attrs|
       new(
-        :ensure         => :present,
-        :name           => attrs["name"],
-        :id             => attrs["id"]
+        :ensure => :present,
+        :name   => attrs[:name],
+        :id     => attrs[:id]
       )
     end
   end
@@ -42,9 +42,11 @@ Puppet::Type.type(:trove_datastore).provide(
       fail("Failed to create datastore #{@resource[:name]}")
     end
 
-    if trove_manage(['trove-manage', 'datastore_update',
-                     "#{@resource[:name]}", "#{@resource[:version]}"]) != 0
-      fail("Failed to set version for datastore #{@resource[:name]}")
+    if @resource[:version]
+      if trove_manage(['trove-manage', 'datastore_update',
+                       "#{@resource[:name]}", "#{@resource[:version]}"]) != 0
+        fail("Failed to set version for datastore #{@resource[:name]}")
+      end
     end
   end
 
